@@ -188,7 +188,6 @@ def main(args=None):
 
 Environment Variables:
     GRACEDB_SERVICE_URL   (can be overridden by --service-url)
-    HTTP_PROXY            (can be overridden by --proxy)
     X509_USER_PROXY
     X509_USER_CERT
     X509_USER_KEY
@@ -209,8 +208,6 @@ Longer strings will be truncated.""" % {
 
     from optparse import OptionParser
     op = OptionParser(usage=usage)
-    op.add_option("-p", "--proxy", dest="proxy",
-                  help="HTTP Proxy", metavar="PROXY[:PORT]")
     op.add_option("-s", "--service-url", dest="service",
                   help="GraCEDb Service URL", metavar="URL")
     op.add_option("-f", "--filename", dest="filename",
@@ -273,7 +270,11 @@ Longer strings will be truncated.""" % {
         else:
             pass
 
-    proxy = options.proxy or os.environ.get('HTTP_PROXY', None)
+    # warn users about depreciation
+    warning("The gracedb_legacy CLI has been deprecated and "
+        "will be removed in a future release. Please use the updated "
+        "gracedb CLI or available API tools for your workflow.")
+
     service = options.service or \
               os.environ.get('GRACEDB_SERVICE_URL', None) or \
               DEFAULT_SERVICE_URL
@@ -281,17 +282,6 @@ Longer strings will be truncated.""" % {
     # Compile dict of kwargs for instantiating the client class
     client_args = {}
 
-    # Process proxy args
-    proxyport = None
-    if proxy and proxy.find(':') > 0:
-        try:
-            proxy, proxyport = proxy.split(':')
-            proxyport = int(proxyport)
-        except:
-            op.error("Malformed proxy: '%s'" % proxy)
-    client_args['proxy_host'] = proxy
-    client_args['proxy_port'] = proxyport
-
     # Auth args
     client_args['force_noauth'] = options.force_noauth
     client_args['username'] = options.username
