@@ -72,7 +72,7 @@ class _GraceDbLogStream(object):
                 return
             try:
                 self._gracedb.writeLog(self._graceid, text)
-            except:
+            except Exception:
                 # If writeLog() fails, then print a message to stderr and keep
                 # going. This is one rare circumstance where we must catch all
                 # exceptions. If the logging thread crashes, then it will stop
