@@ -6,7 +6,7 @@ pytestmark = pytest.mark.integration
 
 def test_ping(client):
     response = client.ping()
-    assert response.status == 200
+    assert response.status_code == 200
 
 
 @pytest.mark.parametrize(
