@@ -4,6 +4,7 @@ import pytest
 import shlex
 
 from ligo.gracedb.cli.client import CommandLineInterface
+from ligo.gracedb.exceptions import HTTPError
 
 # Apply module-level marks
 pytestmark = [pytest.mark.cli, pytest.mark.integration]
@@ -46,7 +47,7 @@ def test_create_event():
     out = response.json()
 
     # Check output
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['group'] == 'Test'
     assert out['pipeline'] == 'gstlal'
     assert out['search'] is None
@@ -68,7 +69,7 @@ def test_get_event():
     out = response.json()
 
     # Check data
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['group'] == 'Test'
     assert out['pipeline'] == 'gstlal'
     assert out['search'] == 'LowMass'
@@ -82,7 +83,7 @@ def test_update_event():
     cmd = 'create event Test gstlal {event_file} LowMass '.format(
         event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     out = response.json()
     gid = out['graceid']
 
@@ -90,11 +91,9 @@ def test_update_event():
     filename = os.path.join(TEST_DATA_DIR, 'cbc-lm2.xml')
     cmd = 'update event {gid} {filename}'.format(gid=gid, filename=filename)
     response = run_CLI_test(cmd)
-    out2 = response.json()
 
     # Check response
-    assert response.status == 202
-    assert out2 == {}
+    assert response.status_code == 202
 
     # Replace event response is useless so we get the event and check it
     cmd = 'get event {gid}'.format(gid=gid)
@@ -102,7 +101,7 @@ def test_update_event():
     out3 = response.json()
 
     # Check data
-    assert response.status == 200
+    assert response.status_code == 200
     assert out3['graceid'] == out['graceid']
     assert out3['gpstime'] != out['gpstime']  # gpstime should have changed
 
@@ -113,7 +112,7 @@ def test_search_events():
     cmd = 'create event Test gstlal {event_file}'.format(
         event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     out = response.json()
     gid = out['graceid']
 
@@ -149,13 +148,13 @@ def test_labels():
     out = response.json()
 
     # Check response
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Get event and check
     cmd = 'get event {gid}'.format(gid=gid)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['labels'] == [label]
 
     # Get label ---------------------------------------------------------------
@@ -164,7 +163,7 @@ def test_labels():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['name'] == label
 
     # List labels -------------------------------------------------------------
@@ -173,24 +172,22 @@ def test_labels():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert len(out['labels']) == 1
     assert out['labels'][0]['name'] == label
 
     # Remove label ------------------------------------------------------------
     cmd = 'remove label {gid} {label}'.format(gid=gid, label=label)
     response = run_CLI_test(cmd)
-    out = response.json()
 
     # Check response
-    assert response.status == 204
-    assert out == {}
+    assert response.status_code == 204
 
     # Get event and check
     cmd = 'get event {gid}'.format(gid=gid)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['labels'] == []
 
 
@@ -213,7 +210,7 @@ def test_logs_files():
     out = response.json()
 
     # Test output
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['comment'] == out['comment']
     assert out['filename'] == os.path.basename(filename)
     assert sorted(out['tag_names']) == sorted(tags)
@@ -224,7 +221,7 @@ def test_logs_files():
     out = response.json()
 
     # Test output
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['comment'] == out['comment']
     assert out['filename'] == fname
     assert sorted(out['tag_names']) == sorted(tags)
@@ -235,7 +232,7 @@ def test_logs_files():
     out = response.json()
 
     # Test output
-    assert response.status == 200
+    assert response.status_code == 200
     comments = [l['comment'] for l in out['log']]
     assert comment in comments
 
@@ -249,7 +246,7 @@ def test_logs_files():
     cmd = 'list files {gid}'.format(gid=gid, filename=fname)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 200
+    assert response.status_code == 200
     assert len(out) >= 2
     assert fname in out
     assert fname + ',0' in out
@@ -271,7 +268,7 @@ def test_tags():
         gid=gid, comment=comment, filename=filename, tags=",".join(tags))
     out = run_CLI_test(cmd).json()
     log_N = out['N']
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['comment'] == out['comment']
     assert out['filename'] == os.path.basename(filename)
     assert sorted(out['tag_names']) == sorted(tags)
@@ -280,7 +277,7 @@ def test_tags():
     tag = 'tag3'
     cmd = 'add tag {gid} {N} {tag}'.format(gid=gid, N=log_N, tag=tag)
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Tag response for events is not helpful. So we have to get the full log
     cmd = 'get log {gid} {N}'.format(gid=gid, N=log_N)
@@ -288,7 +285,7 @@ def test_tags():
     out = response.json()
 
     # Check output
-    assert response.status == 200
+    assert response.status_code == 200
     assert sorted(out['tag_names']) == sorted(tags + [tag])
 
     # List tags ---------------------------------------------------------------
@@ -297,7 +294,7 @@ def test_tags():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert len(out['tags']) == 3
     tags_list = [t['name'] for t in out['tags']]
     assert sorted(tags_list) == sorted(tags + [tag])
@@ -305,7 +302,7 @@ def test_tags():
     # Remove tag from log -----------------------------------------------------
     cmd = 'remove tag {gid} {N} {tag}'.format(gid=gid, N=log_N, tag=tag)
     response = run_CLI_test(cmd)
-    assert response.status == 204
+    assert response.status_code == 204
 
     # Tag response for events is not helpful. So we have to get the full log
     cmd = 'get log {gid} {N}'.format(gid=gid, N=log_N)
@@ -313,7 +310,7 @@ def test_tags():
     out = response.json()
 
     # Check output
-    assert response.status == 200
+    assert response.status_code == 200
     assert sorted(out['tag_names']) == sorted(tags)
     assert tag not in out['tag_names']
 
@@ -335,7 +332,7 @@ def test_create_superevent():
     out = response.json()
 
     # Check response content
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['category'] == 'Test'
     assert sorted(out['gw_events']) == sorted([gid1, gid2])
     assert sorted(out['labels']) == ['EM_READY', 'INJ']
@@ -392,7 +389,7 @@ def test_add_event_to_superevent():
     sid = out['superevent_id']
 
     # Check contents
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['category'] == 'Test'
     assert out['preferred_event'] == gid1
     assert out['gw_events'] == [gid1]
@@ -431,7 +428,7 @@ def test_remove_event_from_superevent():
     sid = out['superevent_id']
 
     # Check contents
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['category'] == 'Test'
     assert out['preferred_event'] == gid1
     assert sorted(out['gw_events']) == sorted([gid1, gid2])
@@ -439,11 +436,9 @@ def test_remove_event_from_superevent():
     # Remove event 2 from superevent
     cmd = 'remove event {sid} {gid}'.format(sid=sid, gid=gid2)
     response = run_CLI_test(cmd)
-    out = response.json()
 
     # Check response
-    assert response.status == 204
-    assert out == {}
+    assert response.status_code == 204
 
     # Get superevent and make sure event 2 is not in it
     cmd = 'get superevent {sid}'.format(sid=sid)
@@ -459,10 +454,10 @@ def test_update_superevent():
     cmd = 'create event Test gstlal {event_file}'.format(
         event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response1 = run_CLI_test(cmd)
-    assert response1.status == 201
+    assert response1.status_code == 201
     gid1 = response1.json()['graceid']
     response2 = run_CLI_test(cmd)
-    assert response2.status == 201
+    assert response2.status_code == 201
     gid2 = response2.json()['graceid']
 
     # Setup: create superevent
@@ -470,7 +465,7 @@ def test_update_superevent():
            '--category=Test').format(p_ev=gid1)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 201
+    assert response.status_code == 201
     sid = out['superevent_id']
 
     # Update superevent -------------------------------------------------------
@@ -480,7 +475,7 @@ def test_update_superevent():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['t_start'] == 4
     assert out['t_0'] == 5
     assert out['t_end'] == 6
@@ -494,7 +489,7 @@ def test_update_grbevent():
     cmd = 'create event Test Fermi {event_file} GRB'.format(
         event_file=os.path.join(TEST_DATA_DIR, 'fermi-test.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     initial_data = response.json()
     gid = initial_data['graceid']
 
@@ -505,18 +500,27 @@ def test_update_grbevent():
     cmd = ('update grbevent {gid} --redshift={rs} --designation="{des}" '
            '--ra={ra}').format(gid=gid, rs=redshift, des=designation,
                                ra=ra)
-    response = run_CLI_test(cmd)
-    assert response.status == 200
-    new_data = response.json()
+    try:
+        response = run_CLI_test(cmd)
+        new_data = response.json()
 
-    # Compare results
-    initial_grb_params = initial_data['extra_attributes']['GRB']
-    new_grb_params = new_data['extra_attributes']['GRB']
-    assert new_grb_params['ra'] == ra
-    assert new_grb_params['redshift'] == redshift
-    assert new_grb_params['designation'] == designation
-    assert new_grb_params['ra'] != initial_grb_params['ra']
-    assert new_grb_params['redshift'] != initial_grb_params['redshift']
+        # Even though they're test GRB events, unprivileged users
+        # can't update GRB events. So try to catch a 200 status
+        # in the case of an admin or grb user, and 403 otherwise.
+        # This came up with setting up the gitlab integration instance.
+
+        assert response.status_code == 200
+        # Compare results
+        initial_grb_params = initial_data['extra_attributes']['GRB']
+        new_grb_params = new_data['extra_attributes']['GRB']
+        assert new_grb_params['ra'] == ra
+        assert new_grb_params['redshift'] == redshift
+        assert new_grb_params['designation'] == designation
+        assert new_grb_params['ra'] != initial_grb_params['ra']
+        assert new_grb_params['redshift'] != initial_grb_params['redshift']
+
+    except HTTPError as e:
+        assert e.status_code == 403
 
 
 def test_confirm_as_gw():
@@ -532,7 +536,7 @@ def test_confirm_as_gw():
     response = run_CLI_test(cmd)
     out = response.json()
     sid = out['superevent_id']
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['gw_id'] is None
 
     # Confirm as GW
@@ -541,7 +545,7 @@ def test_confirm_as_gw():
     out = response.json()
 
     # Check output
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['superevent_id'] == sid
     assert out['gw_id'] is not None
     assert out['gw_id'].startswith('TGW')
@@ -553,7 +557,7 @@ def test_search_superevents():
     cmd = 'create event Test gstlal {event_file}'.format(
         event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     gid = response.json()['graceid']
 
     # Setup: create superevent
@@ -561,7 +565,7 @@ def test_search_superevents():
            '--category=Test').format(p_ev=gid)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 201
+    assert response.status_code == 201
     sid = out['superevent_id']
 
     # Search superevents ------------------------------------------------------
@@ -586,35 +590,47 @@ def test_permissions():
     cmd = 'create event Test gstlal {event_file}'.format(
         event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     gid = response.json()['graceid']
 
     # Setup: create superevent
     cmd = 'create superevent 1 2 3 {p_ev} --category=Test'.format(p_ev=gid)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 201
+    assert response.status_code == 201
     sid = out['superevent_id']
 
     # Expose superevent
     cmd = 'expose {sid}'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+    try:
+        response = run_CLI_test(cmd)
+        out = response.json()
 
-    # Check response
-    assert response.status == 200
-    assert isinstance(out, list)
-    assert len(out) == 3
+        # Check response-- this will be 200 for admins and
+        # em_advocates, or 403 for everyone else, like th
+        # gitlab runner.
+        assert response.status_code == 200
+        assert isinstance(out, list)
+        assert len(out) == 3
+    except HTTPError as e:
+        assert e.status_code == 403
 
     # Hide superevent
     cmd = 'hide {sid}'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+    try:
+        response = run_CLI_test(cmd)
+        out = response.json()
 
-    # Check response
-    assert response.status == 200
-    assert isinstance(out, list)
-    assert len(out) == 0
+        # Check response-- same rules apply for exposing:
+        # Note that unauthorized users will get the 403 response
+        # at the permissions check even if the superevent is not
+        # exposed. So if the previous test 200'ed, then in theory
+        # this one will too if everything worked.
+        assert response.status_code == 200
+        assert isinstance(out, list)
+        assert len(out) == 0
+    except HTTPError as e:
+        assert e.status_code == 403
 
 
 def test_voevents():
@@ -623,7 +639,7 @@ def test_voevents():
     cmd = 'create event Test gstlal {event_file} --offline' \
         .format(event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     out = response.json()
     gid = out['graceid']
 
@@ -632,7 +648,7 @@ def test_voevents():
     cmd = 'create log {gid} "fake skymap" {filename}'.format(
         gid=gid, filename=filename)
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Creation ----------------------------------------------------------------
     cmd = ('create voevent {gid} UP --skymap-filename={skymap} --hardware-inj '
@@ -643,7 +659,7 @@ def test_voevents():
     voevent_N = out['N']
 
     # Check response
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['N'] == voevent_N
     assert out['voevent_type'] == 'UP'
 
@@ -653,7 +669,7 @@ def test_voevents():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['N'] == voevent_N
     assert out['voevent_type'] == 'UP'
 
@@ -663,7 +679,7 @@ def test_voevents():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert len(out['voevents']) == 1
     assert out['voevents'][0]['N'] == voevent_N
     assert out['voevents'][0]['voevent_type'] == 'UP'
@@ -675,7 +691,7 @@ def test_emobservations():
     cmd = 'create event Test gstlal {event_file} --offline' \
         .format(event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     out = response.json()
     gid = out['graceid']
 
@@ -705,11 +721,14 @@ def test_emobservations():
                 start_time_list=join_s(start_time_list))
     cmd += " --comment='fake comment'"
     response = run_CLI_test(cmd)
+    print("yay1", response)
     out = response.json()
+    print("yay2", out)
+    print("yay3", type(out))
     emo_N = out['N']
 
     # Check response
-    assert response.status == 201
+    assert response.status_code == 201
     assert out['comment'] == 'fake comment'
     assert len(out['footprints']) == len(ra_list)
     assert out['group'] == group
@@ -720,7 +739,7 @@ def test_emobservations():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['N'] == emo_N
     assert out['comment'] == 'fake comment'
     assert len(out['footprints']) == len(ra_list)
@@ -732,7 +751,7 @@ def test_emobservations():
     out = response.json()
 
     # Check response
-    assert response.status == 200
+    assert response.status_code == 200
     assert out['observations'][0]['N'] == emo_N
     assert out['observations'][0]['comment'] == 'fake comment'
     assert len(out['observations'][0]['footprints']) == len(ra_list)
@@ -745,7 +764,7 @@ def test_signoffs():
     cmd = 'create event Test gstlal {event_file}'.format(
         event_file=os.path.join(TEST_DATA_DIR, 'cbc-lm.xml'))
     response = run_CLI_test(cmd)
-    assert response.status == 201
+    assert response.status_code == 201
     gid = response.json()['graceid']
 
     # Setup: create superevent
@@ -753,82 +772,92 @@ def test_signoffs():
            '--category=Test').format(p_ev=gid)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 201
+    assert response.status_code == 201
     sid = out['superevent_id']
 
     # Setup: apply ADVREQ label
     cmd = 'add label {sid} ADVREQ'.format(sid=sid)
     response = run_CLI_test(cmd)
     out = response.json()
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Create signoff ----------------------------------------------------------
     cmd = 'create signoff {sid} ADV OK "looks good"'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+    try:
+        response = run_CLI_test(cmd)
+        out = response.json()
 
-    # Check response
-    assert response.status == 201
-    assert out['status'] == 'OK'
-    assert out['comment'] == 'looks good'
-    assert out['instrument'] == ''
-    assert out['signoff_type'] == 'ADV'
+        # Check response
+        assert response.status_code == 201
+        assert out['status'] == 'OK'
+        assert out['comment'] == 'looks good'
+        assert out['instrument'] == ''
+        assert out['signoff_type'] == 'ADV'
 
-    # Get signoff ----------------------------------------------------------
-    cmd = 'get signoff {sid} ADV'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+        # Define this session as an authorized session. The rest of the tests
+        # are sensible only if this one passes. This is admittedly something
+        # that needs to be run offline by an admin unless i can think of a more
+        # clever way of doing it.
+        authorized_user = True
 
-    # Check response
-    assert response.status == 200
-    assert out['status'] == 'OK'
-    assert out['comment'] == 'looks good'
-    assert out['instrument'] == ''
-    assert out['signoff_type'] == 'ADV'
+    except HTTPError as e:
+        assert e.status_code == 403
+        authorized_user = False
 
-    # List signoff ----------------------------------------------------------
-    cmd = 'list signoffs {sid}'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+    if authorized_user:
+        # Get signoff ------------------------------------------------------
+        cmd = 'get signoff {sid} ADV'.format(sid=sid)
+        response = run_CLI_test(cmd)
+        out = response.json()
 
-    # Check response
-    assert response.status == 200
-    assert len(out['signoffs']) == 1
-    assert out['signoffs'][0]['status'] == 'OK'
-    assert out['signoffs'][0]['comment'] == 'looks good'
-    assert out['signoffs'][0]['instrument'] == ''
-    assert out['signoffs'][0]['signoff_type'] == 'ADV'
+        # Check response
+        assert response.status_code == 200
+        assert out['status'] == 'OK'
+        assert out['comment'] == 'looks good'
+        assert out['instrument'] == ''
+        assert out['signoff_type'] == 'ADV'
 
-    # Update signoff ----------------------------------------------------------
-    cmd = 'update signoff {sid} ADV --status=NO --comment="new"'.format(
-        sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+        # List signoff -----------------------------------------------------
+        cmd = 'list signoffs {sid}'.format(sid=sid)
+        response = run_CLI_test(cmd)
+        out = response.json()
 
-    # Check response
-    assert response.status == 200
-    assert out['status'] == 'NO'
-    assert out['comment'] == 'new'
-    assert out['instrument'] == ''
-    assert out['signoff_type'] == 'ADV'
+        # Check response
+        assert response.status_code == 200
+        assert len(out['signoffs']) == 1
+        assert out['signoffs'][0]['status'] == 'OK'
+        assert out['signoffs'][0]['comment'] == 'looks good'
+        assert out['signoffs'][0]['instrument'] == ''
+        assert out['signoffs'][0]['signoff_type'] == 'ADV'
 
-    # Delete signoff ----------------------------------------------------------
-    cmd = 'delete signoff {sid} ADV'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+        # Update signoff ---------------------------------------------------
+        cmd = 'update signoff {sid} ADV --status=NO --comment="new"'.format(
+            sid=sid)
+        response = run_CLI_test(cmd)
+        out = response.json()
 
-    # Check response
-    assert response.status == 204
-    assert out == {}
+        # Check response
+        assert response.status_code == 200
+        assert out['status'] == 'NO'
+        assert out['comment'] == 'new'
+        assert out['instrument'] == ''
+        assert out['signoff_type'] == 'ADV'
 
-    # List signoff again ------------------------------------------------------
-    cmd = 'list signoffs {sid}'.format(sid=sid)
-    response = run_CLI_test(cmd)
-    out = response.json()
+        # Delete signoff ---------------------------------------------------
+        cmd = 'delete signoff {sid} ADV'.format(sid=sid)
+        response = run_CLI_test(cmd)
 
-    # Check response
-    assert response.status == 200
-    assert len(out['signoffs']) == 0
+        # Check response
+        assert response.status_code == 204
+
+        # List signoff again -----------------------------------------------
+        cmd = 'list signoffs {sid}'.format(sid=sid)
+        response = run_CLI_test(cmd)
+        out = response.json()
+
+        # Check response
+        assert response.status_code == 200
+        assert len(out['signoffs']) == 0
 
 
 def test_ping():
@@ -841,7 +870,7 @@ def test_ping():
 def test_credentials():
     """Test getting credentials from server"""
     response = run_CLI_test('credentials server')
-    assert response.status == 200
+    assert response.status_code == 200
 
 
 # Subcommands for testing 'info' command
