@@ -12,7 +12,7 @@ def test_labels(client, create_obj, obj_type):
     # Add a label
     label1 = 'DQV'
     response = client.writeLabel(obj_id, label1)
-    assert response.status == 201
+    assert response.status_code == 201
     data = response.json()
     # NOTE: events API returns empty response - should be fixed
     if obj_type == 'superevent':
@@ -23,7 +23,7 @@ def test_labels(client, create_obj, obj_type):
     # Add another label
     label2 = 'INJ'
     response = client.writeLabel(obj_id, label2)
-    assert response.status == 201
+    assert response.status_code == 201
     data = response.json()
     # NOTE: events API returns empty response - should be fixed
     if obj_type == 'superevent':
@@ -33,7 +33,7 @@ def test_labels(client, create_obj, obj_type):
 
     # Get list of labels
     response = client.labels(obj_id)
-    assert response.status == 200
+    assert response.status_code == 200
     data = response.json()
     obj_labels = [l['name'] for l in data['labels']]
     assert len(obj_labels) == 2
@@ -42,15 +42,13 @@ def test_labels(client, create_obj, obj_type):
 
     # Pull down an individual label
     response = client.labels(obj_id, label2)
-    assert response.status == 200
+    assert response.status_code == 200
     data = response.json()
     assert data['name'] == label2
 
     # Remove a label
     response = client.removeLabel(obj_id, label1)
-    assert response.status == 204
-    data = response.json()
-    assert data == {}
+    assert response.status_code == 204
 
     # Get event and double check
     if obj_type == 'event':
@@ -58,7 +56,7 @@ def test_labels(client, create_obj, obj_type):
     elif obj_type == 'superevent':
         method = 'superevent'
     response = getattr(client, method)(obj_id)
-    assert response.status == 200
+    assert response.status_code == 200
     data = response.json()
     assert len(data['labels']) == 1
     assert label1 not in data['labels']
