@@ -64,7 +64,7 @@ def test_preliminary_voevent(client, create_obj, obj_type):
 
     # Create VOEvent and check results
     response = client.createVOEvent(obj_id, 'PR', **PRELIMINARY_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     data = response.json()
     assert data['voevent_type'] == 'PR'
     assert data['skymap_type'] == PRELIMINARY_VOEVENT_DATA['skymap_type']
@@ -95,16 +95,16 @@ def test_initial_voevent(client, create_obj, obj_type):
         filename=INITIAL_VOEVENT_DATA['skymap_filename'],
         filecontents="Fake skymap."
     )
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Create a preliminary VOEvent to update
     response = client.createVOEvent(obj_id, 'PR', **PRELIMINARY_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     preliminary_data = response.json()
 
     # Create VOEvent and check results
     response = client.createVOEvent(obj_id, 'IN', **INITIAL_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     data = response.json()
     assert data['voevent_type'] == 'IN'
     assert data['skymap_type'] == INITIAL_VOEVENT_DATA['skymap_type']
@@ -123,7 +123,7 @@ def test_initial_voevent(client, create_obj, obj_type):
 
     # Check citations
     response = client.files(obj_id, data['filename'])
-    assert response.status == 200
+    assert response.status_code == 200
     voevent_file_text = response.read()
     citations_dict = get_citations_dict(obj_id, voevent_file_text)
     assert len(citations_dict) == 1
@@ -142,21 +142,21 @@ def test_update_voevent(client, create_obj, obj_type):
         filename=INITIAL_VOEVENT_DATA['skymap_filename'],
         filecontents="Fake skymap."
     )
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Create a preliminary VOEvent to update
     response = client.createVOEvent(obj_id, 'PR', **PRELIMINARY_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     preliminary_data = response.json()
 
     # Create an initial VOEvent to update
     response = client.createVOEvent(obj_id, 'IN', **INITIAL_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     initial_data = response.json()
 
     # Create VOEvent and check results
     response = client.createVOEvent(obj_id, 'UP', **INITIAL_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     data = response.json()
     assert data['voevent_type'] == 'UP'
     assert data['skymap_type'] == INITIAL_VOEVENT_DATA['skymap_type']
@@ -175,7 +175,7 @@ def test_update_voevent(client, create_obj, obj_type):
 
     # Check citations
     response = client.files(obj_id, data['filename'])
-    assert response.status == 200
+    assert response.status_code == 200
     voevent_file_text = response.read()
     citations_dict = get_citations_dict(obj_id, voevent_file_text)
     assert len(citations_dict) == 2
@@ -196,22 +196,22 @@ def test_retraction_voevent(client, create_obj, obj_type):
         filename=INITIAL_VOEVENT_DATA['skymap_filename'],
         filecontents="Fake skymap."
     )
-    assert response.status == 201
+    assert response.status_code == 201
 
     # Create a preliminary VOEvent to retract
     response = client.createVOEvent(obj_id, 'PR', **PRELIMINARY_VOEVENT_DATA)
-    assert response.status == 201
+    assert response.status_code == 201
     preliminary_data = response.json()
 
     # Create a retraction VOEvent
     response = client.createVOEvent(obj_id, 'RE')
-    assert response.status == 201
+    assert response.status_code == 201
     retraction_data = response.json()
     assert retraction_data['voevent_type'] == 'RE'
 
     # Check citations
     response = client.files(obj_id, retraction_data['filename'])
-    assert response.status == 200
+    assert response.status_code == 200
     voevent_file_text = response.read()
     citations_dict = get_citations_dict(obj_id, voevent_file_text)
     assert len(citations_dict) == 1
