@@ -1,4 +1,5 @@
 import pytest
+import sys
 try:
     from unittest import mock
 except ImportError:  # py < 3
@@ -13,17 +14,19 @@ def test_provide_x509_cert_and_key():
     cert_file = '/tmp/cert_file'
     key_file = '/tmp/key_file'
 
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'), \
-         mock.patch(load_cert_func):  # noqa: E127
+    load_cert_func = 'ligo.gracedb.cert.load_certificate'
+    with mock.patch(load_cert_func):  # noqa: E127
         # Initialize client
         g = GraceDb(cred=(cert_file, key_file))
 
+    # Output credentials:
+    creds = g.show_credentials(print_output=False)
+
     # Check credentials
-    assert len(g.credentials) == 2
+    assert len(g.cert) == 2
     assert g.auth_type == 'x509'
-    assert g.credentials.get('cert_file') == cert_file
-    assert g.credentials.get('key_file') == key_file
+    assert creds.get('cert_file') == cert_file
+    assert creds.get('key_file') == key_file
 
 
 def test_provide_x509_proxy():
@@ -31,17 +34,23 @@ def test_provide_x509_proxy():
     # Set up combined proxy file
     proxy_file = '/tmp/proxy_file'
 
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'), \
-         mock.patch(load_cert_func):  # noqa: E127
+    exists_func = 'os.path.exists'
+    load_cert_func = 'ligo.gracedb.cert.load_certificate'
+    with mock.patch(load_cert_func), \
+         mock.patch(exists_func) as mock_exists_func:  # noqa: E127
+
+        mock_exists_func.return_value = True
         # Initialize client
         g = GraceDb(cred=proxy_file)
 
+    # Output credentials:
+    creds = g.show_credentials(print_output=False)
+
     # Check credentials
-    assert len(g.credentials) == 2
+    assert type(g.cert) == str
     assert g.auth_type == 'x509'
-    assert g.credentials.get('cert_file') == proxy_file
-    assert g.credentials.get('key_file') == proxy_file
+    assert creds.get('cert_file') == proxy_file
+    assert creds.get('key_file') == proxy_file
 
 
 USER_PASS_TEST_DATA = [
@@ -53,22 +62,25 @@ USER_PASS_TEST_DATA = [
 def test_provide_username_and_password(user_and_or_pass):
     """Test client instantiation with provided username and or password"""
 
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'):
-        # Initialize client - should fail if only one of username and
-        # password is provided
-        if not len(user_and_or_pass) == 2:
-            err_str = 'Must provide both username AND password for basic auth'
-            with pytest.raises(RuntimeError, match=err_str):
-                g = GraceDb(**user_and_or_pass)
-        else:
+    # Initialize client - should fail if only one of username and
+    # password is provided
+    if not len(user_and_or_pass) == 2:
+        err_str = 'You must provide both a username and a password '\
+                  'for basic authentication'
+        with pytest.raises(RuntimeError, match=err_str):
             g = GraceDb(**user_and_or_pass)
+    else:
+        g = GraceDb(**user_and_or_pass)
 
-            assert len(g.credentials) == 2
-            assert g.auth_type == 'basic'
-            assert g.credentials.get('username') == \
-                user_and_or_pass.get('username')
-            assert g.credentials.get('password') == \
-                user_and_or_pass.get('password')
+        # Output credentials:
+        creds = g.show_credentials(print_output=False)
+
+        assert len(g.auth) == 2
+        assert g.auth_type == 'basic'
+        assert creds.get('username') == \
+            user_and_or_pass.get('username')
+        assert creds.get('password') == \
+            user_and_or_pass.get('password')
 
 
 def test_provide_all_creds():
@@ -80,18 +92,17 @@ def test_provide_all_creds():
     password = 'pw'
 
     # Initialize client
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'), \
-         mock.patch(load_cert_func):  # noqa: E127
-        g = GraceDb(
-            cred=(cert_file, key_file), username=username, password=password
-        )
+    g = GraceDb(
+        cred=(cert_file, key_file), username=username, password=password
+    )
 
     # Check credentials - should prioritze x509 credentials
-    assert len(g.credentials) == 2
+    creds = g.show_credentials(print_output=False)
+
+    assert len(g.cert) == 2
     assert g.auth_type == 'x509'
-    assert g.credentials.get('cert_file') == cert_file
-    assert g.credentials.get('key_file') == key_file
+    assert creds.get('cert_file') == cert_file
+    assert creds.get('key_file') == key_file
 
 
 def test_x509_credentials_lookup():
@@ -101,19 +112,14 @@ def test_x509_credentials_lookup():
     key_file = '/tmp/key_file'
 
     # Initialize client
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
-    find_x509_func = 'ligo.gracedb.rest.GraceDb._find_x509_credentials'
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'), \
-         mock.patch(load_cert_func), \
-         mock.patch(find_x509_func) as mock_find_x509:  # noqa: E127
+    find_x509_func = 'ligo.gracedb.client.GraceDBClient._get_x509_credentials'
+    with mock.patch(find_x509_func) as mock_find_x509:  # noqa: E127
         mock_find_x509.return_value = (cert_file, key_file)
         g = GraceDb()
 
-    # Check credentials - should prioritze x509 credentials
-    assert len(g.credentials) == 2
-    assert g.auth_type == 'x509'
-    assert g.credentials.get('cert_file') == cert_file
-    assert g.credentials.get('key_file') == key_file
+    # the 'auth_type' variable doesn't get set in this case, but it's
+    # sort of fictitious when self.cert is being mocked.
+    assert len(g.cert) == 2
 
 
 def test_x509_lookup_cert_key_from_envvars():
@@ -127,18 +133,17 @@ def test_x509_lookup_cert_key_from_envvars():
         'X509_USER_CERT': cert_file,
         'X509_USER_KEY': key_file,
     }
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
-    os_environ_func = 'ligo.gracedb.rest.os.environ'
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'), \
-         mock.patch(load_cert_func), \
-         mock.patch.dict(os_environ_func, fake_creds_dict):  # noqa: E127
+    os_environ_func = 'os.environ'
+    with mock.patch.dict(os_environ_func, fake_creds_dict):  # noqa: E127
         g = GraceDb()
 
     # Check credentials - should prioritze x509 credentials
-    assert len(g.credentials) == 2
+    creds = g.show_credentials(print_output=False)
+
+    assert len(g.cert) == 2
     assert g.auth_type == 'x509'
-    assert g.credentials.get('cert_file') == cert_file
-    assert g.credentials.get('key_file') == key_file
+    assert creds.get('cert_file') == cert_file
+    assert creds.get('key_file') == key_file
 
 
 def test_x509_lookup_proxy_from_envvars():
@@ -147,19 +152,18 @@ def test_x509_lookup_proxy_from_envvars():
     proxy_file = '/tmp/proxy_file'
 
     # Initialize client
-    os_environ_func = 'ligo.gracedb.rest.os.environ'
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
+    os_environ_func = 'os.environ'
     mock_environ_dict = {'X509_USER_PROXY': proxy_file}
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'), \
-         mock.patch(load_cert_func), \
-         mock.patch.dict(os_environ_func, mock_environ_dict):  # noqa: E127
+    with mock.patch.dict(os_environ_func, mock_environ_dict):  # noqa: E127
         g = GraceDb()
 
     # Check credentials - should prioritze x509 credentials
-    assert len(g.credentials) == 2
+    creds = g.show_credentials(print_output=False)
+
+    assert type(g.cert) == str
     assert g.auth_type == 'x509'
-    assert g.credentials.get('cert_file') == proxy_file
-    assert g.credentials.get('key_file') == proxy_file
+    assert creds.get('cert_file') == proxy_file
+    assert creds.get('key_file') == proxy_file
 
 
 def test_basic_credentials_lookup():
@@ -170,12 +174,10 @@ def test_basic_credentials_lookup():
         'login': 'fake_user',
         'password': 'fake_password',
     }
-    conn_func = 'ligo.gracedb.rest.GraceDb.set_up_connector'
-    find_x509_func = 'ligo.gracedb.rest.GraceDb._find_x509_credentials'
-    safe_netrc = 'ligo.gracedb.rest.safe_netrc'
-    with mock.patch(conn_func), \
-         mock.patch(find_x509_func) as mock_find_x509, \
-         mock.patch(safe_netrc) as mock_netrc:  # noqa: E127
+    netrc = 'ligo.gracedb.client.netrc'
+    find_x509_func = 'ligo.gracedb.client.GraceDBClient._get_x509_credentials'
+    with mock.patch(find_x509_func) as mock_find_x509, \
+         mock.patch(netrc) as mock_netrc:  # noqa: E127
 
         # Force lookup to not find any X509 credentials
         mock_find_x509.return_value = None
@@ -187,21 +189,21 @@ def test_basic_credentials_lookup():
         g = GraceDb('https://{0}/api/'.format(fake_creds['machine']))
 
         # Check credentials
-        assert len(g.credentials) == 2
+        creds = g.show_credentials(print_output=False)
+
+        assert len(g.auth) == 2
         assert g.auth_type == 'basic'
-        assert g.credentials.get('username') == fake_creds.get('login')
-        assert g.credentials.get('password') == fake_creds.get('password')
+        assert creds.get('username') == fake_creds.get('login')
+        assert creds.get('password') == fake_creds.get('password')
 
 
 @pytest.mark.parametrize("fail_if_noauth", [True, False])
 def test_no_credentials(fail_if_noauth):
     """Test client instantiation with no credentials at all"""
-    conn_func = 'ligo.gracedb.rest.GraceDb.set_up_connector'
-    find_x509_func = 'ligo.gracedb.rest.GraceDb._find_x509_credentials'
-    safe_netrc = 'ligo.gracedb.rest.safe_netrc'
-    with mock.patch(conn_func), \
-         mock.patch(find_x509_func) as mock_find_x509, \
-         mock.patch(safe_netrc) as mock_netrc:  # noqa: E127
+    find_x509_func = 'ligo.gracedb.client.GraceDBClient._get_x509_credentials'
+    netrc = 'ligo.gracedb.client.netrc'
+    with mock.patch(find_x509_func) as mock_find_x509, \
+         mock.patch(netrc) as mock_netrc:  # noqa: E127
 
         # Force lookup to not find any X509 credentials
         mock_find_x509.return_value = None
@@ -210,14 +212,18 @@ def test_no_credentials(fail_if_noauth):
 
         # Initialize client
         if fail_if_noauth:
-            err_str = 'No authentication credentials found.'
+            err_str = 'No authentication credentials could be found'
             with pytest.raises(RuntimeError, match=err_str):
                 g = GraceDb(fail_if_noauth=fail_if_noauth)
         else:
-            g = GraceDb(fail_if_noauth=fail_if_noauth)
+            if sys.version_info[0] > 2:
+                warn_str = 'Authentication credentials not found, proceeding'
+                with pytest.warns(UserWarning, match=warn_str):
+                    g = GraceDb(fail_if_noauth=fail_if_noauth)
+            else:
+                g = GraceDb(fail_if_noauth=fail_if_noauth)
 
             # Check credentials
-            assert len(g.credentials) == 0
             assert g.auth_type is None
 
 
@@ -228,20 +234,17 @@ def test_force_noauth():
     key_file = '/tmp/key_file'
 
     # Initialize client
-    conn_func = 'ligo.gracedb.rest.GraceDb.set_up_connector'
-    environ_dict = 'ligo.gracedb.rest.os.environ'
+    environ_dict = 'os.environ'
     mock_environ_dict = {
         'X509_USER_CERT': cert_file,
         'X509_USER_KEY': key_file,
     }
-    with mock.patch(conn_func), \
-         mock.patch.dict(environ_dict, mock_environ_dict):  # noqa: E127
+    with mock.patch.dict(environ_dict, mock_environ_dict):  # noqa: E127
 
         # Initialize client
         g = GraceDb(force_noauth=True)
 
     # Check credentials
-    assert len(g.credentials) == 0
     assert g.auth_type is None
 
 
@@ -252,14 +255,10 @@ def test_fail_if_noauth(creds_found):
     key_file = '/tmp/key_file'
 
     # Initialize client
-    conn_func = 'ligo.gracedb.rest.GraceDb.set_up_connector'
-    load_cert_func = 'ligo.gracedb.rest.GraceDb._load_certificate'
-    find_x509_func = 'ligo.gracedb.rest.GraceDb._find_x509_credentials'
-    safe_netrc = 'ligo.gracedb.rest.safe_netrc'
-    with mock.patch(conn_func), \
-         mock.patch(load_cert_func), \
-         mock.patch(find_x509_func) as mock_find_x509, \
-         mock.patch(safe_netrc) as mock_netrc:  # noqa: E127
+    find_x509_func = 'ligo.gracedb.client.GraceDBClient._get_x509_credentials'
+    netrc = 'ligo.gracedb.client.netrc'
+    with mock.patch(find_x509_func) as mock_find_x509, \
+         mock.patch(netrc) as mock_netrc:  # noqa: E127
 
         if not creds_found:
             # Force lookup to not find any X509 credentials
@@ -268,25 +267,24 @@ def test_fail_if_noauth(creds_found):
             mock_netrc().authenticators.return_value = None
 
             # Initialize client
-            err_str = 'No authentication credentials found.'
+            err_str = 'No authentication credentials could be found'
             with pytest.raises(RuntimeError, match=err_str):
                 g = GraceDb(fail_if_noauth=True)
         else:
             # Initialize client:
+            mock_find_x509.return_value = (cert_file, key_file)
             g = GraceDb(cred=(cert_file, key_file), fail_if_noauth=True)
 
             # Check credentials
-            assert len(g.credentials) == 2
-            assert g.auth_type == 'x509'
+            assert len(g.cert) == 2
 
 
 def test_force_noauth_and_fail_if_noauth():
-    with mock.patch('ligo.gracedb.rest.GraceDb.set_up_connector'):
-        # Initialize client
-        err_str = ('You have provided conflicting parameters to the client '
-                   'constructor: fail_if_noauth=True and force_noauth=True.')
-        with pytest.raises(ValueError, match=err_str):
-            GraceDb(force_noauth=True, fail_if_noauth=True)
+    # Initialize client
+    err_str = ('You have provided conflicting parameters to the client '
+               'constructor: fail_if_noauth=True and force_noauth=True.')
+    with pytest.raises(ValueError, match=err_str):
+        GraceDb(force_noauth=True, fail_if_noauth=True)
 
 
 @pytest.mark.parametrize(
@@ -349,12 +347,3 @@ def test_set_service_url(safe_client, service_url, api_version):
 
     assert safe_client._service_url == expected_service_url
     assert safe_client._versioned_service_url == expected_versioned_service_url
-
-
-def test_legacy_service_url(safe_client, capsys):
-    service_url = 'fake-service-url'
-    safe_client._service_url = service_url
-    assert safe_client.service_url == service_url
-    stdout = capsys.readouterr().out
-    assert stdout.strip() == \
-        "DEPRECATED: this attribute has been moved to '_service_url'"
