@@ -6,6 +6,11 @@ import six
 
 import pytest
 
+# Import get_mimetype since mimetype mapping can vary
+# on different machines, i.e., locally vs in gitlab CI:
+
+from ligo.gracedb.utils import get_mimetype
+
 
 @pytest.mark.parametrize(
     "group,pipeline,search,offline,labels",
@@ -19,6 +24,7 @@ import pytest
 )
 def test_create_event(safe_client, group, pipeline, search, offline, labels):
     filename = 'file.xml'
+    file_mtype = get_mimetype(filename)
 
     # Mock service info dict
     si_property = 'ligo.gracedb.rest.GraceDb.service_info'
@@ -46,16 +52,18 @@ def test_create_event(safe_client, group, pipeline, search, offline, labels):
 
     # Get args used to call post
     call_args, call_kwargs = mock_post.call_args
-    assert len(call_args) == 2
-    assert len(call_kwargs) == 1
+    assert len(call_args) == 1
+    assert len(call_kwargs) == 2
+    assert 'data' in call_kwargs
     assert 'files' in call_kwargs
-    assert call_kwargs['files'] == [('eventFile', filename, mock_data,)]
+    assert call_kwargs['files'] == {'eventFile': (filename, open_mocker(),
+                                                  file_mtype)}
 
     # Check body (convert to dict)
-    body = dict(call_args[1])
+    body = dict(call_kwargs['data'])
     assert body['group'] == group
     assert body['pipeline'] == pipeline
-    assert body['offline'] == offline
+    assert body['offline'] == str(offline)
     if search:
         assert body['search'] == search
     else:
@@ -64,7 +72,7 @@ def test_create_event(safe_client, group, pipeline, search, offline, labels):
         if isinstance(labels, six.string_types):
             labels = [labels]
         req_labels = []
-        for t in call_args[1]:
+        for t in call_kwargs['data']:
             if t[0] == 'labels':
                 req_labels.append(t[1])
         assert sorted(labels) == sorted(req_labels)
@@ -83,6 +91,7 @@ def test_create_event_from_stdin(safe_client):
     # Set up mock sys.stdin.read
     stdin_obj = 'ligo.gracedb.rest.sys.stdin'
     mock_stdin_data = 'fake stdin data'
+    mock_data_type = 'application/octet-stream'
 
     # Call function
     links_prop = 'ligo.gracedb.rest.GraceDb.links'
@@ -96,11 +105,11 @@ def test_create_event_from_stdin(safe_client):
 
     # Get args used to call post
     call_args, call_kwargs = mock_post.call_args
-    assert len(call_args) == 2
-    assert len(call_kwargs) == 1
+    assert len(call_kwargs) == 2
+    assert 'data' in call_kwargs
     assert 'files' in call_kwargs
-    assert call_kwargs['files'] == [('eventFile', 'initial.data',
-                                     mock_stdin_data,)]
+    assert call_kwargs['files'] == {'eventFile': ('initial.data',
+                                    mock_stdin_data, mock_data_type)}
 
 
 def test_create_event_with_filecontents(safe_client):
@@ -115,6 +124,7 @@ def test_create_event_with_filecontents(safe_client):
 
     # File data
     filename = 'file.xml'
+    file_mtype = get_mimetype(filename)
     filecontents = 'event file contents'
 
     # Call function
@@ -128,10 +138,11 @@ def test_create_event_with_filecontents(safe_client):
 
     # Get args used to call post
     call_args, call_kwargs = mock_post.call_args
-    assert len(call_args) == 2
-    assert len(call_kwargs) == 1
+    assert len(call_args) == 1
+    assert len(call_kwargs) == 2
     assert 'files' in call_kwargs
-    assert call_kwargs['files'] == [('eventFile', filename, filecontents,)]
+    assert call_kwargs['files'] == {'eventFile': (filename, filecontents,
+                                                  file_mtype)}
 
 
 def test_create_event_with_bad_group(safe_client):
@@ -312,7 +323,7 @@ def test_creation_args(
 
     # Check args
     call_args, call_kwargs = mock_post.call_args
-    body = call_kwargs['body']
+    body = call_kwargs['data']
     assert body['t_start'] == t_start
     assert body['t_0'] == t_0
     assert body['t_end'] == t_end
@@ -356,7 +367,7 @@ def test_update_args(safe_client, update_kwargs):
 
     # Check results
     call_args, call_kwargs = mock_patch.call_args
-    body = call_kwargs['body']
+    body = call_kwargs['data']
     assert sorted(list(update_kwargs)) == sorted(list(body))
     for k in update_kwargs:
         assert update_kwargs[k] == body[k]
@@ -373,7 +384,7 @@ def test_add_event(safe_client):
         safe_client.addEventToSuperevent(superevent_id, event_graceid)
 
     call_args, call_kwargs = mock_post.call_args
-    assert call_kwargs['body'] == {'event': event_graceid}
+    assert call_kwargs['data'] == {'event': event_graceid}
 
     template_call_args, template_call_kwargs = mock_template.format.call_args
     assert template_call_args == ()
@@ -445,6 +456,7 @@ def test_get(safe_client):
 def test_replace_event(safe_client, filecontents):
     graceid = 'T123456'
     filename = 'file.xml'
+    file_mtype = get_mimetype(filename)
 
     # Set up mock template
     mock_template = mock.MagicMock()
@@ -476,8 +488,9 @@ def test_replace_event(safe_client, filecontents):
     if filecontents:
         expected_data = filecontents
     else:
-        expected_data = mock_data
-    assert call_kwargs['files'] == [('eventFile', filename, expected_data)]
+        expected_data = open_mocker()
+    assert call_kwargs['files'] == {'eventFile': (filename, expected_data,
+                                                  file_mtype)}
 
 
 def test_get_event(safe_client):
