@@ -80,9 +80,10 @@ def test_write_label(safe_client, is_event):
     label = 'TEST_LABEL'
     if is_event:
         obj_id = 'T123456'
+        request_function = 'ligo.gracedb.client.GraceDBClient.put'
     else:
         obj_id = 'TS190302abc'
-    request_func = 'ligo.gracedb.rest.GraceDb.post_or_put_or_patch'
+        request_function = 'ligo.gracedb.client.GraceDBClient.post'
 
     # Set up templates mock
     mock_template = mock.MagicMock()
@@ -96,21 +97,19 @@ def test_write_label(safe_client, is_event):
     # Set up allowed_labels mock
     si_prop = 'ligo.gracedb.rest.GraceDb.service_info'
     mock_si_dict = {'labels': [label]}
-    with mock.patch(request_func) as mock_rf, \
-         mock.patch(si_prop, mock_si_dict), \
+    with mock.patch(si_prop, mock_si_dict), \
+         mock.patch(request_function) as mock_rf, \
          mock.patch(template_prop, mock_template_dict):  # noqa: E127
         safe_client.writeLabel(obj_id, label)
 
     rf_call_args, rf_call_kwargs = mock_rf.call_args
-    assert len(rf_call_args) == 2
+    assert len(rf_call_args) == 1
     assert len(rf_call_kwargs) == 1
-    assert 'body' in rf_call_kwargs
+    assert 'data' in rf_call_kwargs
     if is_event:
-        assert rf_call_args[0] == 'PUT'
-        assert rf_call_kwargs['body'] == {}
+        assert rf_call_kwargs['data'] == {}
     else:
-        assert rf_call_args[0] == 'POST'
-        assert rf_call_kwargs['body'] == {'name': label}
+        assert rf_call_kwargs['data'] == {'name': label}
 
     # Test template call kwargs
     template_call_args, template_call_kwargs = mock_template.format.call_args
