@@ -117,8 +117,8 @@ def test_create_voevent(safe_client, is_event):
     post_call_args, post_call_kwargs = mock_post.call_args
     assert len(post_call_args) == 1
     assert len(post_call_kwargs) == 1
-    assert 'body' in post_call_kwargs
-    request_body = post_call_kwargs['body']
+    assert 'data' in post_call_kwargs
+    request_body = post_call_kwargs['data']
     request_voevent_type = request_body.pop('voevent_type')
     assert request_voevent_type == voevent_type
     for k in voevent_data:
